summaryrefslogtreecommitdiffstats
path: root/kresources/kolab/kabc/contact.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kresources/kolab/kabc/contact.cpp')
-rw-r--r--kresources/kolab/kabc/contact.cpp22
1 files changed, 11 insertions, 11 deletions
diff --git a/kresources/kolab/kabc/contact.cpp b/kresources/kolab/kabc/contact.cpp
index e3032d118..474eafa3d 100644
--- a/kresources/kolab/kabc/contact.cpp
+++ b/kresources/kolab/kabc/contact.cpp
@@ -20,11 +20,11 @@
In addition, as a special exception, the copyright holders give
permission to link the code of this program with any edition of
- the Qt library by Trolltech AS, Norway (or with modified versions
- of Qt that use the same license as Qt), and distribute linked
+ the TQt library by Trolltech AS, Norway (or with modified versions
+ of TQt that use the same license as TQt), and distribute linked
combinations including the two. You must obey the GNU General
Public License in all respects for all of the code used other than
- Qt. If you modify this file, you may extend this exception to
+ TQt. If you modify this file, you may extend this exception to
your version of the file, but you are not obligated to do so. If
you do not wish to do so, delete this exception statement from
your version.
@@ -293,12 +293,12 @@ TQDate Contact::anniversary() const
return mAnniversary;
}
-void Contact::setChildren( const TQString& children )
+void Contact::setChildren( const TQString& tqchildren )
{
- mChildren = children;
+ mChildren = tqchildren;
}
-TQString Contact::children() const
+TQString Contact::tqchildren() const
{
return mChildren;
}
@@ -619,7 +619,7 @@ bool Contact::loadAttribute( TQDomElement& element )
}
break;
case 'c':
- if ( tagName == "children" ) {
+ if ( tagName == "tqchildren" ) {
setChildren( element.text() );
return true;
}
@@ -798,7 +798,7 @@ bool Contact::saveAttributes( TQDomElement& element ) const
writeString( element, "x-logo", mLogoAttachmentName );
if ( !sound().isNull() )
writeString( element, "x-sound", mSoundAttachmentName );
- writeString( element, "children", children() );
+ writeString( element, "tqchildren", tqchildren() );
writeString( element, "gender", gender() );
writeString( element, "language", language() );
savePhoneAttributes( element );
@@ -1115,12 +1115,12 @@ void Contact::setFields( const KABC::Addressee* addressee )
for( TQStringList::Iterator it = customs.begin(); it != customs.end(); ++it ) {
// KABC::Addressee doesn't offer a real way to iterate over customs, other than splitting strings ourselves
// The format is "app-name:value".
- int pos = (*it).find( '-' );
+ int pos = (*it).tqfind( '-' );
if ( pos == -1 ) continue;
TQString app = (*it).left( pos );
if ( app == "KOLAB" ) continue;
TQString name = (*it).mid( pos + 1 );
- pos = name.find( ':' );
+ pos = name.tqfind( ':' );
if ( pos == -1 ) continue;
TQString value = name.mid( pos + 1 );
name = name.left( pos );
@@ -1146,7 +1146,7 @@ void Contact::setFields( const KABC::Addressee* addressee )
// mailer, timezone, productId, sortString, agent, rfc2426 name()
// Things KAddressBook can't handle, so they are saved as unhandled tags:
// initials, children, gender, language
}
// The loading is: xml -> Contact -> addressee, this is the second part
@@ -1146,7 +1146,7 @@ void Contact::setFields( const KABC::Addressee* addressee )
// mailer, timezone, productId, sortString, agent, rfc2426 name()
// Things KAddressBook can't handle, so they are saved as unhandled tags:
- // initials, children, gender, language
+ // initials, tqchildren, gender, language
}
// The loading is: xml -> Contact -> addressee, this is the second part